import { IChainRpcProviders } from '@dynamic-labs/rpc-providers';
import { ProjectSettings } from '@dynamic-labs/sdk-api-core';
import { AuthMode, CoinbaseWalletPreference, MobileExperience, NetworkConfigurationMap, WalletUiUtils } from '@dynamic-labs/types';
import { WalletBookSchema } from '@dynamic-labs/wallet-book';
import { DeepLinkVariant, InternalWalletConnector } from '@dynamic-labs/wallet-connector-core';
type WalletConnectorConstructorOptionsParams = {
    appLogoUrl?: string;
    appName?: string;
    authMode?: AuthMode;
    coinbaseWalletPreference?: CoinbaseWalletPreference;
    chainRpcProviders: IChainRpcProviders;
    deepLinkPreference?: DeepLinkVariant;
    flowNetwork?: 'mainnet' | 'testnet';
    mobileExperience?: MobileExperience;
    networkConfigurations?: NetworkConfigurationMap;
    settings: ProjectSettings;
    useMetamaskSdk?: boolean;
    walletBook: WalletBookSchema;
    walletConnectProjectId?: string;
    walletUiUtils?: WalletUiUtils<InternalWalletConnector>;
    walletConnectPreferredChains?: `eip155:${number}`[];
};
export declare const getWalletConnectorConstructorOptions: ({ appLogoUrl, appName, authMode, coinbaseWalletPreference, chainRpcProviders, deepLinkPreference, flowNetwork, mobileExperience, networkConfigurations, settings, walletConnectProjectId, walletUiUtils, walletBook, walletConnectPreferredChains, useMetamaskSdk, }: WalletConnectorConstructorOptionsParams) => {
    apiProviders: {
        emailOnly?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        magicLink?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        apple?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        bitbucket?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        coinbasesocial?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        discord?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        epicgames?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        facebook?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        farcaster?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        github?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        gitlab?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        google?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        instagram?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        linkedin?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        microsoft?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        twitch?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        twitter?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        blocto?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        banxa?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        coinbaseOnramp?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        dynamic?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        alchemy?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        zerodev?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        telegram?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        turnkey?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        coinbaseWaas?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        sms?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        spotify?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        tiktok?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        line?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        steam?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        shopify?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        zksync?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        kraken?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
        blockaid?: import("@dynamic-labs/sdk-api-core").Provider | undefined;
    };
    appLogoUrl: string | undefined;
    appName: string | undefined;
    authMode: AuthMode | undefined;
    chainRpcProviders: IChainRpcProviders;
    coinbaseWalletPreference: CoinbaseWalletPreference | undefined;
    cosmosNetworks: import("@dynamic-labs/types").GenericNetwork[];
    deepLinkPreference: DeepLinkVariant | undefined;
    eclipseNetworks: import("@dynamic-labs/types").GenericNetwork[];
    evmNetworks: import("@dynamic-labs/types").GenericNetwork[];
    flowNetwork: "mainnet" | "testnet" | undefined;
    mobileExperience: MobileExperience | undefined;
    projectId: string | undefined;
    settings: ProjectSettings;
    solNetworks: import("@dynamic-labs/types").GenericNetwork[];
    starknetNetworks: import("@dynamic-labs/types").GenericNetwork[];
    suiNetworks: import("@dynamic-labs/types").GenericNetwork[];
    useMetamaskSdk: boolean;
    walletBook: {
        groups: Record<string, {
            name: string;
            key: string;
            brand?: {
                alt?: string | undefined;
                primaryColor?: string | undefined;
                spriteId?: string | undefined;
            } | undefined;
            walletOverrides?: Record<string, {
                brand?: {
                    alt?: string | undefined;
                    primaryColor?: string | undefined;
                    spriteId?: string | undefined;
                } | undefined;
                name?: string | undefined;
            }> | undefined;
        }>;
        wallets: Record<string, {
            name: string;
            brand?: {
                alt?: string | undefined;
                primaryColor?: string | undefined;
                spriteId?: string | undefined;
            } | undefined;
            chainGroup?: string | undefined;
            chains?: string[] | undefined;
            desktop?: {
                chromeId?: string | undefined;
                edgeId?: string | undefined;
                firefoxId?: string | undefined;
                native?: string | undefined;
                operaId?: string | undefined;
                safariId?: string | undefined;
                universal?: string | undefined;
            } | undefined;
            eip6963Config?: {
                rdns: string;
            } | undefined;
            filterFromWalletConnect?: boolean | undefined;
            group?: string | undefined;
            hardwareWallets?: string[] | undefined;
            injectedConfig?: {
                chain: string;
                extensionLocators: {
                    value: boolean;
                    flag: string;
                }[];
                providerInterface?: string | undefined;
                walletStandard?: {
                    features: string[];
                    name: string;
                    providerId?: string | undefined;
                } | undefined;
                walletStandardLocators?: {
                    name: string;
                    locator: string;
                }[] | undefined;
                windowLocations?: string[] | undefined;
            }[] | undefined;
            mobile?: {
                android?: string | null | undefined;
                androidId?: string | undefined;
                inAppBrowser?: string | null | undefined;
                ios?: string | null | undefined;
                iosId?: string | undefined;
                native?: string | undefined;
                universal?: string | undefined;
            } | undefined;
            mobileExperience?: "in-app-browser" | "redirect" | undefined;
            shortName?: string | undefined;
            showOnlyIfInstalled?: boolean | undefined;
            switchNetworkOnlyFromWallet?: boolean | undefined;
            walletConnect?: {
                sdks?: string[] | undefined;
            } | undefined;
            walletGroup?: string | undefined;
            walletLimitations?: {
                browserExtension?: {
                    unsupportedEvents?: string[] | undefined;
                    unsupportedMethods?: string[] | undefined;
                } | undefined;
                mobile?: {
                    unsupportedEvents?: string[] | undefined;
                    unsupportedMethods?: string[] | undefined;
                } | undefined;
            } | undefined;
        }>;
    };
    walletConnectPreferredChains: `eip155:${number}`[] | undefined;
    walletConnectorEventsEmitter: import("eventemitter3").EventEmitter<import("dist/packages/wallet-connector-core/src/events").WalletConnectorEvents, any>;
    walletUiUtils: WalletUiUtils<import("@dynamic-labs/wallet-connector-core").WalletConnectorCore.WalletConnector>;
};
export {};
